:orphan:

===================
 Table of Contents
===================

Welcome to the documentation for Skyfield,
the pure Python astronomy library
that is accelerated using NumPy vector math!

.. toctree::
   :maxdepth: 2

   installation
   examples
   example-plots
   files
   almanac
   positions
   time
   planets
   stars
   planetary
   kepler-orbits
   earth-satellites
   searches
   elements
   astropy
   api
   api-iokit
   api-time
   api-vectors
   api-ephemeris
   api-topos
   api-almanac
   api-satellites
   api-stars
   api-planetary
   api-position
   api-elements
   api-units
   api-trigonometry
   design
   bibliography
